#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-AlIKXcejU2oDX6Gen9TU8g
key:                  persistent-test-2.13.1.3-AlIKXcejU2oDX6Gen9TU8g
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  0d93dace91b45bd19437412c6a247379
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-AlIKXcejU2oDX6Gen9TU8g
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-EB9x1OzkcSF7yi8fCnO8Ay
    aeson-2.2.2.0-85YNaCYG8Hg3jpVZvW11rh base-4.18.2.1
    blaze-html-0.9.2.0-EyNfVP5ySLz3cPor2DOnoy bytestring-0.11.5.3
    conduit-1.3.6.1-Ebhy3RBYCl0GjWBSgKr2qO containers-0.6.7
    exceptions-0.10.7 hspec-2.11.6-650Zs5dQhManOB4sLbD4k
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-5iFqrqem0LiCwTyGp2dkRN
    monad-control-1.0.3.1-CF4q0dPSixv18e2CyjoZul
    monad-logger-0.3.42-BL64Q08Nzo8JQUoPoLxKnO mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-1TWKEc5YWhQGYYyLJgBq2Y
    quickcheck-instances-0.3.33-23qwVPc7qOHSOB6o3X5Ow
    random-1.2.1.3-9HnDVtmtwMCAuyzxGkvhji
    resourcet-1.2.6-9srQsJ09Mf4Fnt59TzGntH text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-2tkzLnowc7QFbpMlEzGwZw
    unliftio-0.2.25.1-6KPQkQ8JwO74KLgDjnPbqv
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-1CoVa9Q6EKSEUs7sPAJfW1

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

